@@ -202,6 +202,7 @@ def read_dcd(filename, topology=None):
         raise IOError('failed reading DCD file')
 
     # xyz
+    # TODO there might be a way to clean this up
     # noinspection PyShadowingNames
     def _xyz(off1, off2, off3):
         n_byte = np.ndarray((n_structures,), endian + 'i', buffer, offset=off1, strides=(80 + 12 * n_atoms))
@@ -216,7 +217,8 @@ def read_dcd(filename, topology=None):
     z = _xyz(72 + 8 * n_atoms, 76 + 8 * n_atoms, 76 + 12 * n_atoms)
 
     # Create Trajectory and return
-    return Trajectory(np.vstack([x, y, z]), box=np.vstack([box_x, box_y, box_z]), topology=topology)
+    return Trajectory(np.vstack([x, y, z]).reshape(n_structures, n_atoms, 3),
+                      box=np.vstack([box_x, box_y, box_z]).reshape(n_structures, 3), topology=topology)
 
 
 
